%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% View Clusters
% 9 November 2006, Release 0.85
%
% Input:
%
% Output:
%
% Internal Variables:
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp(' ')
disp('--> Running View Clusters')

load ChanNum
cd(strcat('CM',num2str(ChanNum)))
load RayArray; load ClusterInfo; load RayInfo; load FullValues
load FullArray; load FullVectors; load ImpInfoStuff; load SortedVectors
cd ..

% get channel model params based on this channel model number
[n, PLo, LowSigma_s, CapLambda, LowLambda, CapGamma, LowGamma, ...
LowSigma_c, LowSigma_r, LowSigma_phi, L_mean, Delta_CapK, Delta_LowK, ...
nlos, TSV, SynNLOS] = params( ChanNum );

disp(' ')
disp(strcat('Running Channel Model #',num2str(ChanNum)));
fprintf(1,['Model Parameters\n' ...
    '  n = %.4f, PLo = %.4f, LowSigma_s = %.4f\n' ...
    '  CapLambda = %.4f, LowLambda = %.4f, CapGamma = %.4f\n' ...
    '  LowGamma = %.4f, LowSigma_c = %.4f, LowSigma_r = %.4f, LowSigma_phi = %.4f\n' ...
    '  L_mean = %.4f, Delta_CapK = %.4f, Delta_LowK = %.4f\n' ...
    '  nlos = %.4f, TSV = %.4f, SynNLOS = %.4f\n\n'], ...
    n, PLo, LowSigma_s, CapLambda, LowLambda, CapGamma, LowGamma, ...
    LowSigma_c, LowSigma_r, LowSigma_phi, L_mean, Delta_CapK, Delta_LowK, ...
    nlos, TSV, SynNLOS);

disp(strcat('Maximum Number of Realizations:_',num2str(NumChannels)))

CHAN = -1; % initialize to illegal value
while (CHAN>NumChannels || CHAN<1)
    CHAN = input('Input Realization Number to View: ');
end

disp(' ')
disp('Summary:')
disp(strcat(' Number of Clusters...',num2str(NumClusters)))
disp(strcat(' Number of Rays per Cluster...',num2str(NumRaysPerCluster)))
disp(strcat(' Total Number of Rays...',num2str(NumRays)))

% plot out cluster information

figure(1)
stem(20*log10(1e-3+AvePowCluster(:,CHAN)))
grid on
title('Average Power per Cluster')

figure(2)
stem(20*log10(1e-3+InsPowCluster(:,CHAN)))
grid on
title('Instantaneous Power per Cluster')

figure(3)
stem(AoaCluster(:,CHAN))
grid on
title('Cluster AoA')

figure(4)
stem(ToaCluster(:,CHAN))
grid on
title('Cluster ToA')

% plot out ray information

figure(5)
plot(ToaRayArray(:,:,CHAN))
grid on
title('Ray ToA')

figure(6)
plot(AoaRayArray(:,:,CHAN))
grid on
title('Ray AoA')

figure(7)
plot(20*log10(1e-3+AvePowRayArray(:,:,CHAN)))
grid on
title('Ray Ave Pow')

figure(8)
plot(20*log10(1e-3+InsPowRayArray(:,:,CHAN)))
grid on
title('Ray Ins Pow')

% plot out information

figure(9)
plot(20*log10(1e-3+InsPowArray(:,:,CHAN)))
grid on
title('Instantaneous Power')

figure(10)
plot(AoaArray(:,:,CHAN))
grid on
title('AoA')

figure(11)
plot(ToaArray(:,:,CHAN))
grid on
title('ToA')

Doa=180*(mod(Aoa,2*pi)-pi)/pi; % degrees of arrival
figure(12)
hold on
for ClusterIndex=1:NumClusters
    temp1=mod(ClusterIndex,7);
    if temp1==1
        color='b.';
    elseif temp1==2
        color='g.';
    elseif temp1==3
        color='r.';
    elseif temp1==4
        color='c.';
    elseif temp1==5
        color='m.';
    elseif temp1==6
        color='y.';
    else
        color='k.';
    end
    stem3(Toa(:,ClusterIndex,CHAN),Doa(:,ClusterIndex,CHAN),InsPow(:,ClusterIndex,CHAN),color)
end
axis([0 max(max(Toa(:,:,CHAN))) -180 180 0 max(max(InsPow(:,:,CHAN)))])
grid on
title('Ray amplitude vs. AoA and ToA')
xlabel('ToA nS'); ylabel('AoA degrees'); zlabel('Linear Amp');
hold off    
grid on
view(3)

clear Toa Aoa InsPow 

figure(13)
plot(ToaVector(:,CHAN))
grid on
title('ToA')

figure(14)
plot(AoaWrappedVector(:,CHAN))
grid on
title('AoA')

figure(15)
plot(10*log10(1e-4+InsPowVector(:,CHAN)))
grid on
title('InsPow')

colormap('default')
map=colormap;
figure(16)
a=10*log10(1e-4+InsPowVector(:,CHAN));
b=a-min(a); c=b-min(b); d=1+ceil(54*c/max(c)); 
whitebg(16,map(min(d),:))
scatter(flipud(ToaVector(:,CHAN)),flipud(180*AoaWrappedVector(:,CHAN)/pi),10,map(flipud(d),:),'filled') % plot intensity vector up side down
xlabel('ToA nS'); ylabel('AoA degrees')
title('AoA vs. ToA Intensity Plot')
axis([0 max(ToaVector(:,CHAN)) -180 180])

figure(17)
plot(20*log10(1e-3+SortedAmp(:,CHAN)))
grid on
title('Sorted Amplitude')

figure(18)
stem(SortedAng(:,CHAN),'b.')
grid on
title('Sorted Ray AoA')

figure(19)
plot(SortedTime(:,CHAN))
grid on
title('Sorted Time')

return